@@ -1,5 +1,5 @@
 package Net::Async::Webservice::DHL::Types;
-$Net::Async::Webservice::DHL::Types::VERSION = '0.01_5';
+$Net::Async::Webservice::DHL::Types::VERSION = '0.01_6';
 {
   $Net::Async::Webservice::DHL::Types::DIST = 'Net-Async-Webservice-DHL';
 }
@@ -7,10 +7,7 @@ use strict;
 use warnings;
 use Type::Library
     -base,
-    -declare => qw( AsyncUserAgent
-                    UserAgent
-                    Address
-              );
+    -declare => qw( Address );
 use Type::Utils -all;
 use Types::Standard -types;
 use namespace::autoclean;
@@ -20,15 +17,6 @@ use namespace::autoclean;
 
 class_type Address, { class => 'Net::Async::Webservice::DHL::Address' };
 
-
-duck_type AsyncUserAgent, [qw(POST do_request)];
-duck_type UserAgent, [qw(post request)];
-
-coerce AsyncUserAgent, from UserAgent, via {
-    require Net::Async::Webservice::DHL::SyncAgentWrapper;
-    Net::Async::Webservice::DHL::SyncAgentWrapper->new({ua=>$_});
-};
-
 1;
 
 __END__
@@ -43,7 +31,7 @@ Net::Async::Webservice::DHL::Types - type library for DHL
 
 =head1 VERSION
 
-version 0.01_5
+version 0.01_6
 
 =head1 DESCRIPTION
 
@@ -56,16 +44,6 @@ for use with L<Net::Async::Webservice::DHL>.
 
 Instance of L<Net::Async::Webservice::DHL::Address>.
 
-=head2 C<AsyncUserAgent>
-
-Duck type, any object with a C<do_request> and C<POST> methods.
-Coerced from L</UserAgent> via
-L<Net::Async::Webservice::DHL::SyncAgentWrapper>.
-
-=head2 C<UserAgent>
-
-Duck type, any object with a C<request> and C<post> methods.
-
 =head1 AUTHOR
 
 Gianni Ceccarelli <gianni.ceccarelli@net-a-porter.com>
